@@ -1,4 +1,4 @@
-# Copyright 2015 FUJITSU LIMITED
+# Copyright 2015-2017 FUJITSU LIMITED
 # (C) Copyright 2015,2016 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
@@ -11,14 +11,12 @@
 # or implied. See the License for the specific language governing permissions and limitations under
 # the License.
 
-import logging
+from oslo_log import log as logging
 import pymysql
 
 from monasca_notification.common.repositories.base import base_repo
 from monasca_notification.common.repositories import exceptions as exc
 
-import six
-
 
 log = logging.getLogger(__name__)
 
@@ -26,21 +24,9 @@ log = logging.getLogger(__name__)
 class MysqlRepo(base_repo.BaseRepo):
     def __init__(self, config):
         super(MysqlRepo, self).__init__(config)
-        if 'ssl' in config['mysql']:
-            self._mysql_ssl = config['mysql']['ssl']
-        else:
-            self._mysql_ssl = None
-
-        if 'port' in config['mysql']:
-            self._mysql_port = config['mysql']['port']
-        else:
-            #
-            # If port isn't specified in the config file,
-            # set it to the default value.
-            #
-            self._mysql_port = 3306
-
+        self._mysql_ssl = config['mysql']['ssl'] or None
         self._mysql_host = config['mysql']['host']
+        self._mysql_port = config['mysql']['port']
         self._mysql_user = config['mysql']['user']
         self._mysql_passwd = config['mysql']['passwd']
         self._mysql_dbname = config['mysql']['db']
@@ -52,7 +38,7 @@ class MysqlRepo(base_repo.BaseRepo):
             self._mysql = pymysql.connect(host=self._mysql_host,
                                           port=self._mysql_port,
                                           user=self._mysql_user,
-                                          passwd=six.text_type(self._mysql_passwd).encode('utf-8'),
+                                          passwd=self._mysql_passwd,
                                           db=self._mysql_dbname,
                                           ssl=self._mysql_ssl,
                                           use_unicode=True,
