@@ -1,4 +1,5 @@
 # (C) Copyright 2015-2016 Hewlett Packard Enterprise Development LP
+# Copyright 2017 Fujitsu LIMITED
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,44 +15,37 @@
 # limitations under the License.
 
 import json
-import logging
-import monascastatsd
 import time
 
+from oslo_config import cfg
+from oslo_log import log as logging
+
 from monasca_common.kafka import consumer
 from monasca_common.kafka import producer
 from monasca_notification.common.utils import construct_notification_object
 from monasca_notification.common.utils import get_db_repo
-from processors import base
-from processors import notification_processor
+from monasca_notification.common.utils import get_statsd_client
+from monasca_notification.processors import notification_processor
 
 log = logging.getLogger(__name__)
+CONF = cfg.CONF
 
 
 class RetryEngine(object):
-    def __init__(self, config):
-        self._retry_interval = config['retry']['interval']
-        self._retry_max = config['retry']['max_attempts']
-
-        self._topics = {}
-        self._topics['notification_topic'] = config['kafka']['notification_topic']
-        self._topics['retry_topic'] = config['kafka']['notification_retry_topic']
-
-        self._statsd = monascastatsd.Client(
-            name='monasca',
-            dimensions=base.BaseProcessor.dimensions)
+    def __init__(self):
+        self._statsd = get_statsd_client()
 
         self._consumer = consumer.KafkaConsumer(
-            config['kafka']['url'],
-            config['zookeeper']['url'],
-            config['zookeeper']['notification_retry_path'],
-            config['kafka']['group'],
-            config['kafka']['notification_retry_topic'])
+            CONF.kafka.url,
+            ','.join(CONF.zookeeper.url),
+            CONF.zookeeper.notification_retry_path,
+            CONF.kafka.group,
+            CONF.kafka.notification_retry_topic
+        )
+        self._producer = producer.KafkaProducer(CONF.kafka.url)
 
-        self._producer = producer.KafkaProducer(config['kafka']['url'])
-
-        self._notifier = notification_processor.NotificationProcessor(config)
-        self._db_repo = get_db_repo(config)
+        self._notifier = notification_processor.NotificationProcessor()
+        self._db_repo = get_db_repo()
 
     def run(self):
         for raw_notification in self._consumer:
@@ -65,7 +59,7 @@ class RetryEngine(object):
                 self._consumer.commit()
                 continue
 
-            wait_duration = self._retry_interval - (
+            wait_duration = CONF.retry_engine.interval - (
                 time.time() - notification_data['notification_timestamp'])
 
             if wait_duration > 0:
@@ -74,19 +68,19 @@ class RetryEngine(object):
             sent, failed = self._notifier.send([notification])
 
             if sent:
-                self._producer.publish(self._topics['notification_topic'],
+                self._producer.publish(CONF.kafka.notification_topic,
                                        [notification.to_json()])
 
             if failed:
                 notification.retry_count += 1
                 notification.notification_timestamp = time.time()
-                if notification.retry_count < self._retry_max:
+                if notification.retry_count < CONF.retry_engine.max_attempts:
                     log.error(u"retry failed for {} with name {} "
                               u"at {}.  "
                               u"Saving for later retry.".format(notification.type,
                                                                 notification.name,
                                                                 notification.address))
-                    self._producer.publish(self._topics['retry_topic'],
+                    self._producer.publish(CONF.kafka.notification_retry_topic,
                                            [notification.to_json()])
                 else:
                     log.error(u"retry failed for {} with name {} "
@@ -95,6 +89,6 @@ class RetryEngine(object):
                               .format(notification.type,
                                       notification.name,
                                       notification.address,
-                                      self._retry_max))
+                                      CONF.retry_engine.max_attempts))
 
             self._consumer.commit()
